@@ -30,7 +30,7 @@ extern "C" {
 #define MagickLibVersion  0x708
 #define MagickLibVersionText  "7.0.8"
 #define MagickLibVersionNumber  6,0,0
-#define MagickLibAddendum  "-29"
+#define MagickLibAddendum  "-38"
 #define MagickLibInterface  6
 #define MagickLibMinInterface  6
 #if defined(_WINDOWS)
@@ -40,14 +40,14 @@ extern "C" {
 #    define MagickPlatform "x86"
 #  endif
 #else
-#define MagickPlatform  "armv6"
+#define MagickPlatform  "aarch64"
 #endif
 #define MagickppLibVersionText  "7.0.8"
 #define MagickppLibVersionNumber  4:0:0
-#define MagickppLibAddendum  "-29"
+#define MagickppLibAddendum  "-38"
 #define MagickppLibInterface  4
 #define MagickppLibMinInterface  4
-#define MagickReleaseDate  "2019-03-12"
+#define MagickReleaseDate  "2019-04-09"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
